nc_gm_to_prj: Get projection from NetCDF-CF Grid Mapping
Description
Takes NetCDF-CF grid mapping attributes and returns
a proj4 string.
Usage
nc_gm_to_prj(x)
# S3 method for data.frame
nc_gm_to_prj(x)
# S3 method for list
nc_gm_to_prj(x)
Value
A proj4 string.
Arguments
x
list or data.frame of attributes of the grid mapping variable
as returned by ncdf or ncdf4's get attributes functions or ncmeta's nc_grid_mapping_atts.
Details
The WGS84 datum is used as a default if one os not provided
in the grid mapping.
If only a semi_major axis is provided, a sperical earth is assumed.